Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(98)

Unified Diff: third_party/WebKit/Source/core/frame/FrameView.cpp

Issue 2020103002: Fix sticky constraints and update sticky layer positions recursively after scroll. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Mark sticky positioned objects for positioned movement after frameview scroll. Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/LayoutTests/fast/css/sticky/sticky-clip-rel-child-expected.html ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Source/core/frame/FrameView.cpp
diff --git a/third_party/WebKit/Source/core/frame/FrameView.cpp b/third_party/WebKit/Source/core/frame/FrameView.cpp
index f881a6042a874b94b9ee6295408a6c25b0d0dcb8..90e2cf0a4c6d17d3c787b7df3e58e79eb2cb8d06 100644
--- a/third_party/WebKit/Source/core/frame/FrameView.cpp
+++ b/third_party/WebKit/Source/core/frame/FrameView.cpp
@@ -1609,12 +1609,11 @@ void FrameView::updateLayersAndCompositingAfterScrollIfNeeded()
if (!hasViewportConstrainedObjects())
return;
// Update sticky position objects which are stuck to the viewport.
for (const auto& viewportConstrainedObject : *m_viewportConstrainedObjects) {
LayoutObject* layoutObject = viewportConstrainedObject;
- PaintLayer* layer = toLayoutBoxModelObject(layoutObject)->layer();
if (layoutObject->style()->position() == StickyPosition)
- layer->updateLayerPosition();
+ layoutObject->setNeedsPositionedMovementLayout();
chrishtr 2016/05/31 20:19:53 What about sticky objects that are not stuck to th
flackr 2016/05/31 20:38:52 This is already handled by PaintLayerScrollableAre
}
@@ -1609,12 +1609,11 @@ void FrameView::updateLayersAndCompositingAfterScrollIfNeeded()
if (!hasViewportConstrainedObjects())
return;
- // Update sticky position objects which are stuck to the viewport.
+ // Mark sticky position objects which are stuck to the viewport for positioned movement.
for (const auto& viewportConstrainedObject : *m_viewportConstrainedObjects) {
LayoutObject* layoutObject = viewportConstrainedObject;
// If there fixed position elements, scrolling may cause compositing layers to change.
« no previous file with comments | « third_party/WebKit/LayoutTests/fast/css/sticky/sticky-clip-rel-child-expected.html ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698